#
# repos.py
# Python class defining a collection of /etc/yum.repos.d/*.repo files
#
# Copyright (C) 2006  Red Hat, Inc. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2.  This program is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY expressed or
# implied, including the implied warranties of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.  You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA. Any Red Hat trademarks that are incorporated in the source code or
# documentation are not subject to the GNU General Public License and may
# only be used or replicated with the express permission of Red Hat, Inc.
#
# Red Hat Author: David Cantrell <dcantrell@redhat.com>
#

import os
from yum.config import YumConf
from repoman.repofile import RepoFile

class Repos:
	def __init__(self):
		yc = YumConf()
		self.repofiles = []
		self.repodir = None

		for repodir in yc.reposdir:
			if not os.path.isdir(repodir):
				continue

			self.repodir = repodir

			lines = os.listdir(repodir)
			for file in lines:
				if file[-5:] == '.repo':
					t = repodir + '/' + file
					self.repofiles.append(RepoFile(t))

	def getRepoFiles(self):
		return self.repofiles

	def getStanzaByName(self, name):
		retval = None

		for repofile in self.getRepoFiles():
			try:
				retval = repofile.getStanzaByName(name)
				break
			except KeyError:
				continue

		return retval

	def write(self):
		for repofile in self.getRepoFiles():
			try:
				repofile.write()
			except Exception, e:
				raise e
